@@ -9,17 +9,17 @@ import os
 
 #{ Initialization
 def _init_externals():
-	"""Initialize external projects by putting them into the path"""
-	for module in ('async', 'smmap'):
-		sys.path.append(os.path.join(os.path.dirname(__file__), 'ext', module))
-		
-		try:
-			__import__(module)
-		except ImportError:
-			raise ImportError("'%s' could not be imported, assure it is located in your PYTHONPATH" % module)
-		#END verify import
-	#END handel imports
-	
+    """Initialize external projects by putting them into the path"""
+    for module in ('smmap',):
+        sys.path.append(os.path.join(os.path.dirname(__file__), 'ext', module))
+
+        try:
+            __import__(module)
+        except ImportError:
+            raise ImportError("'%s' could not be imported, assure it is located in your PYTHONPATH" % module)
+        #END verify import
+    #END handel imports
+
 #} END initialization
 
 _init_externals()
@@ -27,12 +27,11 @@ _init_externals()
 __author__ = "Sebastian Thiel"
 __contact__ = "byronimo@gmail.com"
 __homepage__ = "https://github.com/gitpython-developers/gitdb"
-version_info = (0, 5, 3)
+version_info = (0, 6, 0)
 __version__ = '.'.join(str(i) for i in version_info)
 
 
 # default imports
-from db import *
-from base import *
-from stream import *
-
+from gitdb.base import *
+from gitdb.db import *
+from gitdb.stream import *
